# coding: utf-8

"""
   Python SDK for OpenFGA

   API version: 0.1
   Website: https://openfga.dev
   Documentation: https://openfga.dev/docs
   Support: https://discord.gg/8naAwJfWN6
   License: [Apache-2.0](https://github.com/openfga/python-sdk/blob/main/LICENSE)

   NOTE: This file was auto generated by OpenAPI Generator (https://openapi-generator.tech). DO NOT EDIT.
"""

try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openfga_sdk.configuration import Configuration


class UsersetTreeTupleToUserset(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'tupleset': 'str',
        'computed': 'list[Computed]'
    }

    attribute_map = {
        'tupleset': 'tupleset',
        'computed': 'computed'
    }

    def __init__(self, tupleset=None, computed=None, local_vars_configuration=None):  # noqa: E501
        """UsersetTreeTupleToUserset - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._tupleset = None
        self._computed = None
        self.discriminator = None

        self.tupleset = tupleset
        self.computed = computed

    @property
    def tupleset(self):
        """Gets the tupleset of this UsersetTreeTupleToUserset.  # noqa: E501


        :return: The tupleset of this UsersetTreeTupleToUserset.  # noqa: E501
        :rtype: str
        """
        return self._tupleset

    @tupleset.setter
    def tupleset(self, tupleset):
        """Sets the tupleset of this UsersetTreeTupleToUserset.


        :param tupleset: The tupleset of this UsersetTreeTupleToUserset.  # noqa: E501
        :type tupleset: str
        """
        if self.local_vars_configuration.client_side_validation and tupleset is None:  # noqa: E501
            raise ValueError("Invalid value for `tupleset`, must not be `None`")  # noqa: E501

        self._tupleset = tupleset

    @property
    def computed(self):
        """Gets the computed of this UsersetTreeTupleToUserset.  # noqa: E501


        :return: The computed of this UsersetTreeTupleToUserset.  # noqa: E501
        :rtype: list[Computed]
        """
        return self._computed

    @computed.setter
    def computed(self, computed):
        """Sets the computed of this UsersetTreeTupleToUserset.


        :param computed: The computed of this UsersetTreeTupleToUserset.  # noqa: E501
        :type computed: list[Computed]
        """
        if self.local_vars_configuration.client_side_validation and computed is None:  # noqa: E501
            raise ValueError("Invalid value for `computed`, must not be `None`")  # noqa: E501

        self._computed = computed

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UsersetTreeTupleToUserset):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UsersetTreeTupleToUserset):
            return True

        return self.to_dict() != other.to_dict()



import json
import platform
import sys
from typing import Dict
from collections import OrderedDict

from . import __version__ as openfga_sdk_version

try:
    import urllib3

    urllib3_version = urllib3.__version__
except ModuleNotFoundError:
    urllib3_version = ""

try:
    import six

    six_version = six.__version__
except ModuleNotFoundError:
    six_version = ""

try:
    import dateutil

    dateutil_version = dateutil.__version__
except ModuleNotFoundError:
    dateutil_version = ""

try:
    import aiohttp

    aiohttp_version = aiohttp.__version__
except ModuleNotFoundError:
    aiohttp_version = ""


def info() -> Dict[str, Dict[str, str]]:
    """
    Generate information for a bug report.
    Based on the requests package help utility module.
    """
    try:
        platform_info = {
            "system": platform.system(),
            "release": platform.release(),
        }
    except OSError:
        platform_info = {"system": "Unknown", "release": "Unknown"}

    implementation = platform.python_implementation()

    if implementation == "CPython":
        implementation_version = platform.python_version()
    elif implementation == "PyPy":
        pypy_version_info = sys.pypy_version_info  # type: ignore[attr-defined]
        implementation_version = (
            f"{pypy_version_info.major}."
            f"{pypy_version_info.minor}."
            f"{pypy_version_info.micro}"
        )
        if pypy_version_info.releaselevel != "final":
            implementation_version = "".join(
                [implementation_version, pypy_version_info.releaselevel]
            )
    else:
        implementation_version = "Unknown"

    return OrderedDict(
        {
            "platform": platform_info,
            "implementation": {
                "name": implementation,
                "version": implementation_version,
            },
            "openfga_sdk": {"version": openfga_sdk_version},
            "dependencies": {
                "urllib3": {"version": urllib3_version},
                "six": {"version": six_version},
                "python-dateutil": {"version": dateutil_version},
                "aiohttp": {"version": aiohttp_version},
            },
        }
    )


def main() -> None:
    """Pretty-print the bug information as JSON."""
    print(json.dumps(info(), indent=2))


if __name__ == "__main__":
    main()
